---
title: Viperin
tableColumns:
    article:
      doi: 10.1038/s41586-020-2762-2
      abstract: |
        Viperin is an interferon-induced cellular protein that is conserved in animals. It has previously been shown to inhibit the replication of multiple viruses by producing the ribonucleotide 3'-deoxy-3',4'-didehydro (ddh)-cytidine triphosphate (ddhCTP), which acts as a chain terminator for viral RNA polymerase2. Here we show that eukaryotic viperin originated from a clade of bacterial and archaeal proteins that protect against phage infection. Prokaryotic viperins produce a set of modified ribonucleotides that include ddhCTP, ddh-guanosine triphosphate (ddhGTP) and ddh-uridine triphosphate (ddhUTP). We further show that prokaryotic viperins protect against T7 phage infection by inhibiting viral polymerase-dependent transcription, suggesting that it has an antiviral mechanism of action similar to that of animal viperin. Our results reveal a class of potential natural antiviral compounds produced by bacterial immune systems.
    Sensor: Unknown
    Activator: Direct
    Effector: Nucleotide modifying
    PFAM: PF04055, PF13353
---

# Viperin
## Description
 
Viperins, for "Virus Inhibitory Protein, Endoplasmic Reticulum-associated, INterferon-inducible", are antiviral enzymes whose expression is stimulated by interferons in eukaryotic cells. They are important components of eukaryotic innate immunity, and present antiviral activity against a wide diversity of viruses, including double-stranded DNA viruses, single-strand RNA viruses and retroviruses (1).  

Recently,  Viperin-like enzymes were found in prokaryotes (pVips).  Strikingly, like their eukaryotic counter-part with eukaryotic viruses, pVips provide clear protection against phage infection to their host, and therefore constitute a new defense system (2). Like eukaryotic Viperins, pVips produce modified nucleotides that block phage transcription, acting as chain terminators. They constitute a form of chemical defense. A recent study reported that pVips can be found in around 0.5% of prokaryotic genomes (3).

## Molecular mechanism


Fig.1: Catalytic activity of human Viperin generates ddhCTP (Ebrahimi et al. al., 2020)

Viperins are members of the radical S-adenosylmethionine (rSAM) superfamily. This group of enzymes use a [4Fe-4S] cluster to cleave S-adenosylmethionine (SAM) reductively, generating a radical which is generally transferred to a substrate. It was demonstrated that through their [4Fe-4S] cluster catalytic activity, eukaryotic viperins convert a ribonucleotide, the cytidine triphosphate (CTP) into a modified ribonucleotide, the 3'-deoxy-3',4'-didehydro-CTP (ddhCTP) (4,5). 

Prokaryotic Viperins also convert ribonucleotides triphosphate into modified ribonucleotides, but contrary to their eukaryotic counterparts can use a diversity of substrates to produce  ddhCTP,  or ddh-guanosine triphosphate (ddhGTP), or ddh-uridine triphosphate (ddhUTP), or several of these nucleotides for certain pVips (2).

Compared to the initial ribonucleotide triphosphate, the modified ddh-nucleotide product of Viperins lacks a hydroxyl group at the 3′ carbon of the ribose (Fig.1). The ddh-nucleotides produced by Viperins can be used as substrates by some viral RNA polymerases. Because of their lost hydroxyl group at the 3’carbon of the ribose, once incorporated into the newly forming viral RNA chain, these ddh-nucleotides act as chain terminators. By preventing further polymerization of the viral RNA chain, ddh-nucleotides can inhibit viral replication (2,4,5).

## Example of genomic structure

The Viperin system is composed of one protein: pVip.

Here is an example found in the RefSeq database: 

![viperin](/viperin/Viperin.svg){max-width=750px}

Viperin system in the genome of *Moritella yayanosii* is composed of 1 protein: pVip (WP_112711942.1).

## Distribution of the system among prokaryotes

The Viperin system is present in a total of 85 different species.

Among the 22k complete genomes of RefSeq, this system is present in 118 genomes (0.5 %).

![viperin](/viperin/Distribution_Viperin.svg){max-width=750px}

*Proportion of genome encoding the Viperin system for the 14 phyla with more than 50 genomes in the RefSeq database.* 

## Structure

### Viperin

::molstar-pdbe-plugin
---
height: 700
dataUrl: /viperin/Viperin__pVip-plddts_95.08271.pdb
---
::

## Experimental validation

Viperin systems were experimentally validated using:

Subsystem pVip6 with a system from *Selenomonas ruminatium* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip7 with a system from *Fibrobacter sp. UWT3* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip9 with a system from *Vibrio porteresiae* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip12 with a system from *Ruegeria intermedia* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip15 with a system from *Coraliomargarita akajimensis* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip21 with a system from *Lewinella persica* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip32 with a system from *Phormidium sp. OSCR GFM* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip34 with a system from *Cryomorphaceae bacterium* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip37 with a system from *Shewanella sp. cp20* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip39 with a system from *Burkholderiales-76 (UID4002)* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip44 with a system from *Chondromyces crocatus* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip46 with a system from *Photobacterium swingsii* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip57 with a system from *Flavobacterium lacus* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip58 with a system from *Pseudoalteromonas ulvae* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip60 with a system from *Lacinutrix sp. JCM 13824* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip61 with a system from *Euryarchaeota archaeon SCGC AG-487_M08* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip62 with a system from *Fibrobacteria bacterium* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

Subsystem pVip63 with a system from *Pseudoalteromonas sp. XI10* in *Escherichia coli* has an anti-phage effect against T7 (Bernheim et al., 2020)

## Relevant abstracts

::article-doi-list
---
items:
    - doi: 10.1038/s41586-020-2762-2

---
::

